@@ -3,8 +3,8 @@
 This project provides low-level bindings for D3D12 API. It utilizes `rust-bindgen` for generating raw bindings (unlike `d3d12-rs` crate), but aims for providing idiomatic APIs (unlike the raw D3D12 wrappers from `winapi` or `windows-rs` crates).
 
 ## Features
-- type-safe wrappers for D3D12 enumerations and bit flags
-- wrappers for `ID3D12*` interfaces and POD structs (the latter are marked as `#[repr(transparent)]` so that they can be used as a drop-in replacement for the native types, but expose type-safe getters and setters)
+- wrappers for `ID3D12*` interfaces and POD structs. The latter are marked as `#[repr(transparent)]` so that they can be used as a drop-in replacement for the native types, but expose type-safe getters and setters. The setters have two forms: `with_*(mut self, ...) -> Self` and `set_*(&mut self, ...) -> &mut Self` and are intended for building new structures and modifying the existing ones, respectively
+- type-safe wrappers for D3D12 enumerations and bit flags (see [enum_wrappers.rs](src/enum_wrappers.rs) for details)
 - `D3D12` and `DXGI` prefixes have been stripped from all types, functions and enum variants (e.g. this library exposes `CommandListType::Direct` instead of `D3D12_COMMAND_LIST_TYPE_DIRECT`) since it's very likely that people who use it already know the name of the API it wraps (it's mentioned in the crate name after all), and do not need to be constantly reminded about it :) Also all type and function names have been reshaped with respect to the official Rust code style (e.g. `get_gpu_descriptor_handle_for_heap_start` instead of `GetGPUDescriptorHandleForHeapStart`). Note that most, but *not* all the enum variant names have been converted yet, so some of them will be changed in future versions
 - D3D12 Agility SDK is integrated into the library and shipped along with it (see `heterogeneous_multiadapter.rs` for an example of exporting required symbols). Current SDK version is `1.600.10`
 - PIX markers (they require enabling `pix` feature which is off by default not to introduce a dependency on `WinPixEventRuntime.dll` for people who don't need it)
@@ -25,18 +25,20 @@ debug_controller.enable_object_auto_name();
 ```
 - create a descriptor heap:
 ```rust
-let heap = device.create_descriptor_heap(
+let rtv_heap = device
+    .create_descriptor_heap(
         &DescriptorHeapDesc::default()
-            .set_heap_type(heap_type)
-            .set_num_descriptors(descriptor_count)
-            .set_flags(flags),
-    ).expect("cannot create descriptor heap");
-
-heap.set_name(name).expect("cannot set name on descriptor heap");
+            .with_heap_type(DescriptorHeapType::Rtv)
+            .with_num_descriptors(FRAMES_IN_FLIGHT),
+    )
+    .expect("Cannot create RTV heap");
+rtv_heap
+    .set_name("RTV heap")
+    .expect("Cannot set RTV heap name");
 ```
 - check if cross-adapter textures are supported:
 ```rust
-let mut feature_data = FeatureDataD3DOptions::default();
+let mut feature_data = FeatureDataOptions::default();
 device
     .check_feature_support(Feature::D3D12Options, &mut feature_data)
     .expect("Cannot check feature support");
@@ -45,25 +47,25 @@ let cross_adapter_textures_supported = feature_data.cross_adapter_row_major_text
 ```
 - create mesh shader PSO:
 ```rust
-let ms_bytecode = ShaderBytecode::from_bytes(&mesh_shader);
-let ps_bytecode = ShaderBytecode::from_bytes(&pixel_shader);
+let ms_bytecode = ShaderBytecode::new(&mesh_shader);
+let ps_bytecode = ShaderBytecode::new(&pixel_shader);
 
 let pso_subobjects_desc = MeshShaderPipelineStateDesc::default()
-    .set_root_signature(root_signature)
-    .set_ms_bytecode(&ms_bytecode)
-    .set_ps_bytecode(&ps_bytecode)
-    .set_rasterizer_state(
-        &RasterizerDesc::default().set_depth_clip_enable(false),
+    .with_root_signature(root_signature)
+    .with_ms_bytecode(&ms_bytecode)
+    .with_ps_bytecode(&ps_bytecode)
+    .with_rasterizer_state(
+        RasterizerDesc::default().with_depth_clip_enable(false),
     )
-    .set_blend_state(&BlendDesc::default())
-    .set_depth_stencil_state(
-        &DepthStencilDesc::default().set_depth_enable(false),
+    .with_blend_state(BlendDesc::default())
+    .with_depth_stencil_state(
+        DepthStencilDesc::default().with_depth_enable(false),
     )
-    .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
-    .set_rtv_formats(&[Format::R8G8B8A8Unorm]);
+    .with_primitive_topology_type(PrimitiveTopologyType::Triangle)
+    .with_rtv_formats(&[Format::R8G8B8A8Unorm]);
 
 let pso_desc = PipelineStateStreamDesc::default()
-    .set_pipeline_state_subobject_stream(
+    .with_pipeline_state_subobject_stream(
         pso_subobjects_desc.as_byte_stream(),
     );
 
@@ -770,7 +772,7 @@ impl Factory {
         &self,
         command_queue: &CommandQueue,
         window_handle: HWND,
-        desc: &SwapchainDesc,
+        desc: &SwapChainDesc,
     ) -> DxResult<Swapchain> {
         let mut temp_hw_swapchain: *mut IDXGISwapChain1 = std::ptr::null_mut();
         unsafe {
@@ -1337,18 +1339,15 @@ impl Device {
         ByteCount,
     ) {
         let mut placed_subresource_footprints: Vec<PlacedSubresourceFootprint> =
-            Vec::with_capacity(num_subresources as usize);
-        unsafe {
-            placed_subresource_footprints.set_len(num_subresources as usize)
-        }
+            vec![
+                PlacedSubresourceFootprint::default();
+                num_subresources as usize
+            ];
 
-        let mut num_rows: Vec<u32> =
-            Vec::with_capacity(num_subresources as usize);
-        unsafe { num_rows.set_len(num_subresources as usize) }
+        let mut num_rows: Vec<u32> = vec![0; num_subresources as usize];
 
         let mut row_sizes: Vec<ByteCount> =
-            Vec::with_capacity(num_subresources as usize);
-        unsafe { row_sizes.set_len(num_subresources as usize) }
+            vec![ByteCount(0); num_subresources as usize];
 
         let mut total_bytes = 0u64;
 
@@ -1670,7 +1669,7 @@ impl DescriptorHeap {
     }
 }
 
-#[derive(Copy, Clone, Debug)]
+#[derive(Copy, Clone, Debug, Hash, PartialOrd, Ord, PartialEq, Eq)]
 #[repr(transparent)]
 pub struct CpuDescriptorHandle {
     pub hw_handle: D3D12_CPU_DESCRIPTOR_HANDLE,
@@ -1688,7 +1687,7 @@ impl CpuDescriptorHandle {
     }
 }
 
-#[derive(Debug, Copy, Clone)]
+#[derive(Debug, Copy, Clone, Hash, PartialOrd, Ord, PartialEq, Eq)]
 #[repr(transparent)]
 pub struct GpuDescriptorHandle {
     pub hw_handle: D3D12_GPU_DESCRIPTOR_HANDLE,
@@ -1705,7 +1704,7 @@ impl GpuDescriptorHandle {
     }
 }
 
-#[derive(Debug)]
+#[derive(Debug, Hash, PartialOrd, Ord, PartialEq, Eq)]
 #[repr(transparent)]
 pub struct Resource {
     this: *mut ID3D12Resource,
@@ -1816,7 +1815,7 @@ impl CommandAllocator {
 
 assert_eq_size!(CommandList, *mut ID3D12GraphicsCommandList6);
 
-#[derive(Debug)]
+#[derive(Debug, Hash, PartialOrd, Ord, PartialEq, Eq)]
 #[repr(transparent)]
 pub struct CommandList {
     this: *mut ID3D12GraphicsCommandList6,
@@ -2475,35 +2474,26 @@ impl CommandList {
                 + std::mem::size_of::<u64>(),
         ) * num_subresources;
 
-        let mut allocated_memory: Vec<u8> =
-            Vec::with_capacity(allocation_size.0 as usize);
-        unsafe {
-            allocated_memory.set_len(allocation_size.0 as usize);
-
-            // let allocation =
-            //     allocated_memory.as_mut_ptr() as *mut std::ffi::c_void;
-
-            let destination_desc = destination_resource.get_desc();
-            let device = destination_resource.get_device()?;
-            let (layouts, num_rows, row_sizes_in_bytes, required_size) = device
-                .get_copyable_footprints(
-                    &destination_desc,
-                    first_subresouce,
-                    num_subresources,
-                    intermediate_offset,
-                );
-            self.update_subresources(
-                destination_resource,
-                intermediate_resource,
+        let destination_desc = destination_resource.get_desc();
+        let device = destination_resource.get_device()?;
+        let (layouts, num_rows, row_sizes_in_bytes, required_size) = device
+            .get_copyable_footprints(
+                &destination_desc,
                 first_subresouce,
                 num_subresources,
-                required_size,
-                &layouts,
-                &num_rows,
-                &row_sizes_in_bytes,
-                source_data,
-            )
-        }
+                intermediate_offset,
+            );
+        self.update_subresources(
+            destination_resource,
+            intermediate_resource,
+            first_subresouce,
+            num_subresources,
+            required_size,
+            &layouts,
+            &num_rows,
+            &row_sizes_in_bytes,
+            source_data,
+        )
     }
 }
 
